@@ -97,8 +97,28 @@ class VideoToAudioHandler(FileSystemEventHandler):
                 skip_delete = True
                 return
 
-            mined_line = get_text_event(last_note)
+            # Just for safety
+            if not last_note:
+                if get_config().anki.update_anki:
+                    last_note = anki.get_last_anki_card()
+                if get_config().features.backfill_audio:
+                    last_note = anki.get_cards_by_sentence(gametext.current_line_after_regex)
+
+            # Get Info of line mined
+            line_cutoff = None
+            start_line = None
+            if selected_lines:
+                start_line = selected_lines[0]
+                mined_line = get_mined_line(last_note, selected_lines)
+                line_cutoff = selected_lines[-1].get_next_time()
+            else:
+                mined_line = get_text_event(last_note)
+                if mined_line:
+                    start_line = mined_line
+                    if mined_line.next:
+                        line_cutoff = mined_line.next.time
             gsm_state.last_mined_line = mined_line
+
             if os.path.exists(video_path) and os.access(video_path, os.R_OK):
                 logger.debug(f"Video found and is readable: {video_path}")
             if get_config().obs.minimum_replay_size and not ffmpeg.is_video_big_enough(video_path,
@@ -109,24 +129,6 @@ class VideoToAudioHandler(FileSystemEventHandler):
                     f"Video was unusually small, potentially empty! Check OBS for Correct Scene Settings! Path: {video_path}")
                 return
 
-            # Just for safety
-            if not last_note:
-                if get_config().anki.update_anki:
-                    last_note = anki.get_last_anki_card()
-                if get_config().features.backfill_audio:
-                    last_note = anki.get_cards_by_sentence(gametext.current_line_after_regex)
-            line_cutoff = None
-            start_line = None
-            if mined_line:
-                start_line = mined_line
-                if mined_line.next:
-                    line_cutoff = mined_line.next.time
-
-            if selected_lines:
-                start_line = selected_lines[0]
-                mined_line = get_mined_line(last_note, selected_lines)
-                line_cutoff = selected_lines[-1].get_next_time()
-
             if last_note:
                 logger.debug(last_note.to_json())
             note = anki.get_initial_card_info(last_note, selected_lines)
